==> common-dto-4.2-sources.jar: fr/ird/observe/gson/ImmutableSetAdapter.java <==
package fr.ird.observe.gson;

/*
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2017 - 2018 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.ImmutableSet;
import com.google.common.reflect.TypeParameter;
import com.google.common.reflect.TypeToken;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonParseException;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Set;

/**
 * @author Tony Chemit - dev@tchemit.fr
 */
public class ImmutableSetAdapter implements JsonDeserializer<ImmutableSet<?>> {

    @Override
    public ImmutableSet deserialize(JsonElement json, Type type, JsonDeserializationContext context) throws JsonParseException {

        Type[] actualTypeArguments = ((ParameterizedType) type).getActualTypeArguments();
        Type actualTypeArgument = actualTypeArguments[0];

        Type type2 = setOf(TypeToken.of(actualTypeArgument)).getType();
        Set set = context.deserialize(json, type2);

        return ImmutableSet.copyOf(set);
    }

    static <E> TypeToken<Set<E>> setOf(TypeToken<E> subType) {
        return new TypeToken<Set<E>>() {
        }
                .where(new TypeParameter<E>() {
                }, subType);
    }
}

==> common-dto-4.13-sources.jar: fr/ird/observe/gson/ImmutableSetAdapter.java <==
package fr.ird.observe.gson;

/*
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2017 - 2019 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.ImmutableSet;
import com.google.common.reflect.TypeParameter;
import com.google.common.reflect.TypeToken;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonParseException;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Set;

/**
 * @author Tony Chemit - dev@tchemit.fr
 */
public class ImmutableSetAdapter implements JsonDeserializer<ImmutableSet<?>> {

    public static <E> TypeToken<Set<E>> setOf(TypeToken<E> subType) {
        return new TypeToken<Set<E>>() {
        }
                .where(new TypeParameter<E>() {
                }, subType);
    }

    @Override
    public ImmutableSet deserialize(JsonElement json, Type type, JsonDeserializationContext context) throws JsonParseException {

        Type[] actualTypeArguments = ((ParameterizedType) type).getActualTypeArguments();
        Type actualTypeArgument = actualTypeArguments[0];

        Type type2 = setOf(TypeToken.of(actualTypeArgument)).getType();
        Set set = context.deserialize(json, type2);

        return ImmutableSet.copyOf(set);
    }
}
